.. Turbo-Flask documentation master file, created by
   sphinx-quickstart on Sat Jun 26 15:36:04 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Turbo-Flask
===========

.. toctree::
   :maxdepth: 2

   quickstart
   api

* :ref:`genindex`
* :ref:`search`
